package no.marintek.generic.control;

import java.util.Set;

/**
 * Data structure for values sent from and back to the numerical simulation at a time step. Values are organized in the following hierarchy:
 * <code>{@link SignalEntity} -> Component -> double array</code>.
 * 
 * <ul>
 * <li>A {@link SignalEntity} is a reference to a named part of the numerical model. This can for example be a SIMO body and is referred to by its
 * name.</li>
 * <li>Components are the different components of a {@link SignalEntity}. One component maps to one double array of values from the simulation. For
 * example, a {@link SignalEntity} referring to a SIMO body contains a component named "position" which contains an array of the current position of
 * the body.</li>
 * </ul>
 * 
 * Example:
 * 
 * <pre>
 * {@code
 * Signal measurements = (...);
 * int size = (...);
 * double values[size];
 * SignalEntity anEntity = measurements.getEntity("anEntity");
 * values = anEntity.get("aComponent");
 * }
 * </pre>
 * 
 */
public interface Signal {

	/**
	 * @return a {@link Set} of String IDs for all available components
	 */
	public Set<String> getAvaliableEntities();

	/**
	 * @param id
	 *            Identifier of {@link SignalEntity}
	 * @return a {@link SignalEntity} object with measurements for the given identifier
	 */
	public SignalEntity getEntity(String id);


}